pub enum IbOrderStatus {
ApiPending,
PendingSubmit,
PreSubmitted,
Submitted,
PendingCancel,
ApiCancelled,
Cancelled,
Filled,
Inactive,
}Expand description
Interactive Brokers order status values.
Variants
ApiPending
Order is pending API processing.
PendingSubmit
Order is pending submission.
PreSubmitted
Order has been pre-submitted.
Submitted
Order has been submitted.
PendingCancel
Order is pending cancellation.
ApiCancelled
Order was cancelled by the API.
Cancelled
Order was cancelled.
Filled
Order has been fully filled.
Inactive
Order is inactive.
Implementations
Sourceimpl IbOrderStatus
impl IbOrderStatus
Sourcepub const fn nautilus_status(self) -> NautilusOrderStatus
pub const fn nautilus_status(self) -> NautilusOrderStatus
Converts the IB order status to a Nautilus order status.
Sourcepub const fn is_accepted(self) -> bool
pub const fn is_accepted(self) -> bool
Returns whether this status means an order should be treated as accepted.
Sourcepub const fn is_terminal(self) -> bool
pub const fn is_terminal(self) -> bool
Returns whether this status is terminal for pending spread fill handling.